@@ -38,19 +38,19 @@ class Algorunner:
     def Run(start=None, init=None, stop=None, exit=None, options=None):
         """Starts the algorunner wrapper.
 
-    Convenience method to start the algorithm. Pass the algorithm methods
-    This method blocks forever
+        Convenience method to start the algorithm. Pass the algorithm methods
+        This method blocks forever
 
-    Args:
-        start (function): The entry point of the algorithm. Called for every invocation.
-        init (function): Optional init method. Called for every invocation before the start.
-        stop (function): Optional stop method. Called when the parent pipeline is stopped.
-        exit (function): Optional exit handler. Called before the algorithm is forced to exit.
-                Can be used to clean up resources.
+        Args:
+            start (function): The entry point of the algorithm. Called for every invocation.
+            init (function): Optional init method. Called for every invocation before the start.
+            stop (function): Optional stop method. Called when the parent pipeline is stopped.
+            exit (function): Optional exit handler. Called before the algorithm is forced to exit.
+                    Can be used to clean up resources.
 
-    Returns:
-        Never returns.
-    """
+        Returns:
+            Never returns.
+        """
         algorunner = Algorunner()
         if (start):
             algorunner.loadAlgorithmCallbacks(start, init=init, stop=stop, exit=exit, options=options or config)
@@ -64,6 +64,7 @@ class Algorunner:
         algorunner = Algorunner()
         config.socket['url'] = debug_url
         config.storage['mode'] = 'v1'
+        config.discovery["enable"] = False
         algorunner.loadAlgorithmCallbacks(start, init=init, stop=stop, exit=exit, options=options or config)
         jobs = algorunner.connectToWorker(config)
         gevent.joinall(jobs)
@@ -175,6 +176,7 @@ class Algorunner:
                 'port': options.discovery.get("port")
             }
             self._dataServer = DataServer(options.discovery)
+            self._reportServing(interval=options.discovery.get("servingReportInterval"))
 
     def _initDataAdapter(self, options):
         self._dataAdapter = DataAdapter(options, self._dataServer)
@@ -267,9 +269,10 @@ class Algorunner:
         storingData = dict()
         storageInfo = self._dataAdapter.createStorageInfo(data)
         storingData.update(storageInfo)
-
+        incache = None
         if (self._dataServer and savePaths):
-            self._dataServer.setSendingState(taskId, algorithmData)
+            incache = self._dataServer.setSendingState(taskId, algorithmData, len(encodedData))
+        if(incache):
             storingData.update({'discovery': self._discovery, 'taskId': taskId})
             self._sendCommand(messages.outgoing.storing, storingData)
             self._dataAdapter.setData({'jobId': jobId, 'taskId': taskId, 'data': encodedData})
@@ -280,6 +283,22 @@ class Algorunner:
             Tracer.instance.finish_span(span)
         self._sendCommand(messages.outgoing.done, None)
 
+    def _reportServing(self, interval=None):
+        if(interval is None):
+            return
+        interval = interval / 1000
+
+        def reportInterval():
+            while (True):
+                self._reportServingStatus()
+                gevent.sleep(interval)
+        gevent.spawn(reportInterval)
+
+    def _reportServingStatus(self):
+        isServing = self._dataServer.isServing()
+        if(isServing):
+            self._sendCommand(messages.outgoing.servingStatus, True)
+
     def _stop(self, options):
         try:
             method = self._getMethod('stop')
